Model library - Docs

Skip to content

# Models

## Overview

PreFab accommodates unique predictor and corrector models for each photonic foundry, regularly updated based on recent fabrication data.

Foundry | Process | Latest Version | Latest Dataset | Model Name | Model Tag
--- | --- | --- | --- | --- | ---
ANT | NanoSOI | ANF1 (May 6 2023) | d9 (Feb 6 2024) | ANT_NanoSOI | ANF1-d9
ANT | SiN | ANF1 (May 6 2023) | d1 (Jan 31 2024) | ANT_SiN | ANF1-d1

New models and foundries are to be regularly added. Usage may change. For additional foundry and process models, feel free to contact us.